var group__aom__encoder =
[
    [ "aom_external_partition.h", "aom__external__partition_8h.html", null ],
    [ "aomcx.h", "aomcx_8h.html", null ],
    [ "aom_ext_part_config", "structaom__ext__part__config.html", [
      [ "superblock_size", "structaom__ext__part__config.html#afea4a08073da755d626dc7f7a308922c", null ]
    ] ],
    [ "aom_partition_features_before_none", "structaom__partition__features__before__none.html", [
      [ "f", "structaom__partition__features__before__none.html#a3e68a4613b294ec8ee5a5dbda67d0686", null ],
      [ "f_part2", "structaom__partition__features__before__none.html#ab3f2b4befa941b58b378e2cd8ec401fd", null ]
    ] ],
    [ "aom_partition_features_none", "structaom__partition__features__none.html", [
      [ "f", "structaom__partition__features__none.html#ab342e40d34aa67f83e103307f01ddc08", null ],
      [ "f_terminate", "structaom__partition__features__none.html#a56d6654d19102937664def116a85d5f5", null ]
    ] ],
    [ "aom_partition_features_split", "structaom__partition__features__split.html", [
      [ "f_terminate", "structaom__partition__features__split.html#a91689fc7a77585043a1f688fe7d91454", null ],
      [ "f_prune_rect", "structaom__partition__features__split.html#a950d55955a97e530379a0aeed441196b", null ]
    ] ],
    [ "aom_partition_features_rect", "structaom__partition__features__rect.html", [
      [ "f", "structaom__partition__features__rect.html#a439756ac5789b7b4a4a372c71097632c", null ]
    ] ],
    [ "aom_partition_features_ab", "structaom__partition__features__ab.html", [
      [ "f", "structaom__partition__features__ab.html#a6567b2854b58057776c35b0e6363fe22", null ]
    ] ],
    [ "aom_sb_tpl_features", "structaom__sb__tpl__features.html", [
      [ "available", "structaom__sb__tpl__features.html#a8228b46700a21ab4046492f633312904", null ],
      [ "tpl_unit_length", "structaom__sb__tpl__features.html#af749988972e8c01fb60f721c44a5c25a", null ],
      [ "num_units", "structaom__sb__tpl__features.html#a82bfdcc31c8475f26b32f7abb22cd617", null ],
      [ "intra_cost", "structaom__sb__tpl__features.html#af4010c9b8928177fbf5d5843c148a6c0", null ],
      [ "inter_cost", "structaom__sb__tpl__features.html#ac3943a8049b841846176edd4e0debd1d", null ],
      [ "mc_dep_cost", "structaom__sb__tpl__features.html#ab03f2248d937ac7a288144e21fc0efc1", null ]
    ] ],
    [ "aom_sb_simple_motion_features", "structaom__sb__simple__motion__features.html", [
      [ "unit_length", "structaom__sb__simple__motion__features.html#a7aa12bec07b36b03a28cfb05c8c1e3aa", null ],
      [ "num_units", "structaom__sb__simple__motion__features.html#a2f95654f86af8d033f746850c9464e27", null ],
      [ "block_sse", "structaom__sb__simple__motion__features.html#affcb678b566cc457b8350d918b9e4348", null ],
      [ "block_var", "structaom__sb__simple__motion__features.html#a687222319c4539eb4a0c0590040a7d77", null ]
    ] ],
    [ "aom_sb_features", "structaom__sb__features.html", [
      [ "motion_features", "structaom__sb__features.html#a8306feb95faafa28db0969b28df8a44c", null ],
      [ "tpl_features", "structaom__sb__features.html#a6ed9e89e84705ecf2b57f4675c6fe7a5", null ]
    ] ],
    [ "aom_partition_features", "structaom__partition__features.html", [
      [ "id", "structaom__partition__features.html#a4731d83b9b04f9cfd3893f4f1dbdd080", null ],
      [ "before_part_none", "structaom__partition__features.html#abbf59077401dce7ac4d055514ad80301", null ],
      [ "after_part_none", "structaom__partition__features.html#a57a8ca171132cd4a77632592c7c41192", null ],
      [ "after_part_split", "structaom__partition__features.html#adf54cf17eaf05c05d86c9193094a1f50", null ],
      [ "after_part_rect", "structaom__partition__features.html#a15a457204ef86ff3263440bec4ddc948", null ],
      [ "after_part_ab", "structaom__partition__features.html#a211821af78f8bdaf62a18c235a916093", null ],
      [ "sb_features", "structaom__partition__features.html#adb8aa70a30508890279af5b16e93b28a", null ],
      [ "mi_row", "structaom__partition__features.html#aaee6343bfdea3e083deb4b302ece6a50", null ],
      [ "mi_col", "structaom__partition__features.html#aed1b95e9c03152afc09f5bf181cb43f2", null ],
      [ "frame_width", "structaom__partition__features.html#a67d6bcec5129ee4685c702fb68ceea4f", null ],
      [ "frame_height", "structaom__partition__features.html#ad4f1272c0b5afaedec168eabdfbfa0c5", null ],
      [ "block_size", "structaom__partition__features.html#a8051104747244a265e72d6f0644374df", null ],
      [ "valid_partition_types", "structaom__partition__features.html#afc57251e936f7cf74e842868d778c1ec", null ],
      [ "update_type", "structaom__partition__features.html#a6e3435a7972fafe3c383da042cf96a77", null ],
      [ "qindex", "structaom__partition__features.html#af8688065c0baf3ae4e7bf2c8f20861c4", null ],
      [ "rdmult", "structaom__partition__features.html#ad695bea0d6a1659abd9a9b942ff85227", null ],
      [ "pyramid_level", "structaom__partition__features.html#a8838d71ea72338dd142f0e433642d065", null ],
      [ "has_above_block", "structaom__partition__features.html#a54897d3bdfef80a02c16fbcb76736485", null ],
      [ "above_block_width", "structaom__partition__features.html#a86525024ea9f24ecf0bf31963a345fba", null ],
      [ "above_block_height", "structaom__partition__features.html#a0a5e404813f93f836f012e60220b7c68", null ],
      [ "has_left_block", "structaom__partition__features.html#aedbaf4a1e7751540c15b001a972359cf", null ],
      [ "left_block_width", "structaom__partition__features.html#a79cfe2a0e3e0c15e73b5ede49a5d5f96", null ],
      [ "left_block_height", "structaom__partition__features.html#a23af3dc77a4770dd39e045c633faf65a", null ],
      [ "block_sse", "structaom__partition__features.html#a4b08b7405c4ba9ffedc45a30c694a964", null ],
      [ "block_var", "structaom__partition__features.html#a31fa147e2c5387f2606c03292b85a06f", null ],
      [ "sub_block_sse", "structaom__partition__features.html#a05dea217fcf06d906addb841d95acd98", null ],
      [ "sub_block_var", "structaom__partition__features.html#aa7058c97bb885a6ee60c6104cb239230", null ],
      [ "horz_block_sse", "structaom__partition__features.html#ad35552f6487fd2c82868aae20ac4e67c", null ],
      [ "horz_block_var", "structaom__partition__features.html#a47c3ae1ced8ca3af066f93ba9565b95e", null ],
      [ "vert_block_sse", "structaom__partition__features.html#ab1bb33100eaf6a2a77cc4e1a754eb15b", null ],
      [ "vert_block_var", "structaom__partition__features.html#a34efa7b3edf1a5b9babf0a9c1a74e53c", null ],
      [ "tpl_intra_cost", "structaom__partition__features.html#ab65f3261f8f6a43dfb492c43e2d0afbf", null ],
      [ "tpl_inter_cost", "structaom__partition__features.html#a5d79662e727a19d1111c7d9b030f2d97", null ],
      [ "tpl_mc_dep_cost", "structaom__partition__features.html#a07ddce9d308964422596892e8183e04f", null ]
    ] ],
    [ "aom_partition_decision", "structaom__partition__decision.html", [
      [ "is_final_decision", "structaom__partition__decision.html#a0382eea62fc1c2d512f39204975c2e4a", null ],
      [ "num_nodes", "structaom__partition__decision.html#a538dd9c4e764cd3ea4d2668271873c89", null ],
      [ "partition_decision", "structaom__partition__decision.html#ad92afb344cddb69b412464dda7244ac0", null ],
      [ "current_decision", "structaom__partition__decision.html#add0b1ea35484e23edf1b8f13217ae8b0", null ],
      [ "terminate_partition_search", "structaom__partition__decision.html#a2679a5fbc948af8c30a122dc1ce6a557", null ],
      [ "partition_none_allowed", "structaom__partition__decision.html#a86bc8ec9886ad34550a48fdc62c352ac", null ],
      [ "partition_rect_allowed", "structaom__partition__decision.html#a5332dca7476c9ded1e4f6faee1dd6cc8", null ],
      [ "do_rectangular_split", "structaom__partition__decision.html#abe1fc1a23dd2d7a6cb2eff778b8ee3ba", null ],
      [ "do_square_split", "structaom__partition__decision.html#a076cbd55af72c5eaad9863139a8182b9", null ],
      [ "prune_rect_part", "structaom__partition__decision.html#af2410511da3a9d5172d40d05de5565b4", null ],
      [ "horza_partition_allowed", "structaom__partition__decision.html#a682ec9f4a54f9e1e52731e09b8ff5f79", null ],
      [ "horzb_partition_allowed", "structaom__partition__decision.html#a41b8263d21c799573aa1ce1aef3edec8", null ],
      [ "verta_partition_allowed", "structaom__partition__decision.html#a15374b52d4a5c940a091d7b77b7abc9b", null ],
      [ "vertb_partition_allowed", "structaom__partition__decision.html#a3c0c209683759bdae0daf4e2337ba664", null ],
      [ "partition_horz4_allowed", "structaom__partition__decision.html#ad41b933b59f08ff0f83528e5ee85a64a", null ],
      [ "partition_vert4_allowed", "structaom__partition__decision.html#a2e00d6cfd7c3ef2454224024b5f35c41", null ]
    ] ],
    [ "aom_partition_stats", "structaom__partition__stats.html", [
      [ "rate", "structaom__partition__stats.html#ab01c959aac5c69c5bb801598171360a9", null ],
      [ "dist", "structaom__partition__stats.html#a6855e7cc86f7c00d7358d94b6f096224", null ],
      [ "rdcost", "structaom__partition__stats.html#a88f68df6e27aa77485f2dade868634f9", null ]
    ] ],
    [ "aom_ext_part_funcs", "structaom__ext__part__funcs.html", [
      [ "create_model", "structaom__ext__part__funcs.html#a53c7c5dcc3b0cc4ac165dd0366992f86", null ],
      [ "send_features", "structaom__ext__part__funcs.html#ae3bb6fb4a43da49e22a36a8f67160272", null ],
      [ "get_partition_decision", "structaom__ext__part__funcs.html#a0df62dada4f6083dfa4557f0bebb16c9", null ],
      [ "send_partition_stats", "structaom__ext__part__funcs.html#afeeb0b64960dfd54d116a41ad6dbaba0", null ],
      [ "delete_model", "structaom__ext__part__funcs.html#a00b5dea45726cf43a0407cbd7d09b907", null ],
      [ "decision_mode", "structaom__ext__part__funcs.html#a4710159f9ee2717f81b495e0c72f7b95", null ],
      [ "priv", "structaom__ext__part__funcs.html#a38bf7bd45873982823515d0dff2ec81c", null ]
    ] ],
    [ "aom_roi_map", "structaom__roi__map.html", [
      [ "roi_map", "structaom__roi__map.html#a7d12a1d1074e33fd32077d568e4304d6", null ],
      [ "rows", "structaom__roi__map.html#a70a76ce19292cbdf943a5658b9601fdd", null ],
      [ "cols", "structaom__roi__map.html#a33d4739da69f1885bf7572b99cc9b367", null ],
      [ "delta_q", "structaom__roi__map.html#a85c39484ec01f907a1d50aa969d38ee2", null ],
      [ "delta_lf", "structaom__roi__map.html#a3a37c73fcdcfac9f6f7fec338e746982", null ],
      [ "static_threshold", "structaom__roi__map.html#a68f795675cf54a123c89e2f9dda9063f", null ]
    ] ],
    [ "aom_active_map", "structaom__active__map.html", [
      [ "active_map", "structaom__active__map.html#a8916917bce716b1d954a9f476d98142e", null ],
      [ "rows", "structaom__active__map.html#a0d7ce0e1050137bf9b88e8649ea7aec2", null ],
      [ "cols", "structaom__active__map.html#a3a105e0d8f2643cdc542e2f078b9e6b2", null ]
    ] ],
    [ "aom_scaling_mode", "structaom__scaling__mode.html", [
      [ "h_scaling_mode", "structaom__scaling__mode.html#aa5ea6cc798f31d2af5e68425982f50e5", null ],
      [ "v_scaling_mode", "structaom__scaling__mode.html#a3b535e8839e2bdf05afcd15ec6daa6ce", null ]
    ] ],
    [ "aom_svc_layer_id", "structaom__svc__layer__id.html", [
      [ "spatial_layer_id", "structaom__svc__layer__id.html#af018f2e9cc472827a75b92a78ba6ee4e", null ],
      [ "temporal_layer_id", "structaom__svc__layer__id.html#a9a28c1b126e8d1fdda6e1d881afb66fb", null ]
    ] ],
    [ "aom_svc_params", "structaom__svc__params.html", [
      [ "number_spatial_layers", "structaom__svc__params.html#a3ac79ae856b34c3a8a44e1615ef452d5", null ],
      [ "number_temporal_layers", "structaom__svc__params.html#adae9509ce69067d122d9a4bcae94b340", null ],
      [ "max_quantizers", "structaom__svc__params.html#a3366999bf6b17fa3ad2b2a57092ddcee", null ],
      [ "min_quantizers", "structaom__svc__params.html#a558bc3a8d00cabe8f112c8977e927d0c", null ],
      [ "scaling_factor_num", "structaom__svc__params.html#af29066b136efb3837dfc674d2bcc60f2", null ],
      [ "scaling_factor_den", "structaom__svc__params.html#a89c964e4a3e25c4c76bb20242bee3f6b", null ],
      [ "layer_target_bitrate", "structaom__svc__params.html#a524061efd3e5cb962d364d0d20fd1433", null ],
      [ "framerate_factor", "structaom__svc__params.html#a52a517b31b478cbd4b60d690979cc314", null ]
    ] ],
    [ "aom_svc_ref_frame_config", "structaom__svc__ref__frame__config.html", [
      [ "reference", "structaom__svc__ref__frame__config.html#a2fad59de417585a385f7f3db7faa9a7d", null ],
      [ "ref_idx", "structaom__svc__ref__frame__config.html#ae6f0dece96f18986127eb6c2ee66c210", null ],
      [ "refresh", "structaom__svc__ref__frame__config.html#ab2a4596eadeaf5b7730588367918beda", null ]
    ] ],
    [ "aom_svc_ref_frame_comp_pred", "structaom__svc__ref__frame__comp__pred.html", [
      [ "use_comp_pred", "structaom__svc__ref__frame__comp__pred.html#ab577b1cb23becd2e053da0dac4175a0f", null ]
    ] ],
    [ "AOM_EXT_PART_ABI_VERSION", "group__aom__encoder.html#ga5a44302260efb45ebf560f7fb0b4352b", null ],
    [ "AOM_EXT_PART_SIZE_DIRECT_SPLIT", "group__aom__encoder.html#gae5ea047136d781f9d7eb4c342121b41a", null ],
    [ "AOM_EXT_PART_SIZE_PRUNE_PART", "group__aom__encoder.html#ga29427094de00e8d1883207afcc28b22c", null ],
    [ "AOM_EXT_PART_SIZE_PRUNE_NONE", "group__aom__encoder.html#gaf8d9d8acde0c4a982e80d1dec78ba8ad", null ],
    [ "AOM_EXT_PART_SIZE_TERM_NONE", "group__aom__encoder.html#ga28cc21cd9c9fc1f02818e90772a0baf6", null ],
    [ "AOM_EXT_PART_SIZE_TERM_SPLIT", "group__aom__encoder.html#gaff93c6de790dccd2faaa6556130d0b3b", null ],
    [ "AOM_EXT_PART_SIZE_PRUNE_RECT", "group__aom__encoder.html#ga6ee5804fef84710679f46bb77895aa90", null ],
    [ "AOM_EXT_PART_SIZE_PRUNE_AB", "group__aom__encoder.html#gae2d6be6f94a6e0342f990d45826f9d4e", null ],
    [ "AOM_EXT_PART_SIZE_PRUNE_4_WAY", "group__aom__encoder.html#ga23f13860556f8879c2cef2565b8182a8", null ],
    [ "AOM_EFLAG_NO_REF_LAST", "group__aom__encoder.html#gae272ed6e69ae2a12993565e8176d004b", null ],
    [ "AOM_EFLAG_NO_REF_LAST2", "group__aom__encoder.html#ga50c2560ca6670298cfc614ecae96a391", null ],
    [ "AOM_EFLAG_NO_REF_LAST3", "group__aom__encoder.html#gaa4bc8ae2b977b73f0ef57ba428ca1d2c", null ],
    [ "AOM_EFLAG_NO_REF_GF", "group__aom__encoder.html#gaaef6fe76991abf87edd2f296eee999f8", null ],
    [ "AOM_EFLAG_NO_REF_ARF", "group__aom__encoder.html#ga9e2f989737d63ddf4e987a525d186a46", null ],
    [ "AOM_EFLAG_NO_REF_BWD", "group__aom__encoder.html#ga758649aa6cd9fefb15ad888489884a38", null ],
    [ "AOM_EFLAG_NO_REF_ARF2", "group__aom__encoder.html#gad04799a74215e1b9609f7ccd1766f8c9", null ],
    [ "AOM_EFLAG_NO_UPD_LAST", "group__aom__encoder.html#ga7a55a46970c074b761319c5c46d87b6e", null ],
    [ "AOM_EFLAG_NO_UPD_GF", "group__aom__encoder.html#gaa81cc31f95fd463f51a158050d267a36", null ],
    [ "AOM_EFLAG_NO_UPD_ARF", "group__aom__encoder.html#ga469b4cf5ff76cb30de951e129c25a786", null ],
    [ "AOM_EFLAG_NO_UPD_ENTROPY", "group__aom__encoder.html#gac5a69f04b0bc88f755587a1da815d754", null ],
    [ "AOM_EFLAG_NO_REF_FRAME_MVS", "group__aom__encoder.html#ga31943c4d9e34f90a0691949109c224fd", null ],
    [ "AOM_EFLAG_ERROR_RESILIENT", "group__aom__encoder.html#gaf8d13359c477e5787cf67b6e583317a0", null ],
    [ "AOM_EFLAG_SET_S_FRAME", "group__aom__encoder.html#ga98480541d93f77481d44dfb0896fcdc5", null ],
    [ "AOM_EFLAG_SET_PRIMARY_REF_NONE", "group__aom__encoder.html#ga0f19205f8fb08e9d9aa49403428ff33b", null ],
    [ "AOM_MAX_SEGMENTS", "group__aom__encoder.html#ga58817629f5270c0db0851e354cd6e57c", null ],
    [ "AOM_MAX_LAYERS", "group__aom__encoder.html#ga3589babe0100b5bf7dc7167675014608", null ],
    [ "AOM_MAX_SS_LAYERS", "group__aom__encoder.html#ga9f3d7cfaa6290b207c0ce360ed63ae45", null ],
    [ "AOM_MAX_TS_LAYERS", "group__aom__encoder.html#ga5ecd6f60f02c807e0de37df7b7278f4e", null ],
    [ "aom_ext_part_model_t", "group__aom__encoder.html#ga8ac829090566737c469a7147207e8855", null ],
    [ "aom_ext_part_decision_mode_t", "group__aom__encoder.html#gaca3421fd8424ed3ab48704748a12c9d1", null ],
    [ "aom_ext_part_config_t", "group__aom__encoder.html#ga88539c1f9e72d6ab6f8802ff265539dd", null ],
    [ "aom_partition_features_before_none_t", "group__aom__encoder.html#ga45f71361ba7598dbb347d6f8de8f37b6", null ],
    [ "aom_partition_features_none_t", "group__aom__encoder.html#gaeb906a5b059249c051cb0d2f853aff6c", null ],
    [ "aom_partition_features_split_t", "group__aom__encoder.html#ga00f4961195d6d1d53c045d9675bb4d78", null ],
    [ "aom_partition_features_rect_t", "group__aom__encoder.html#gad09f5b034137ba0981dd5f2dc075b27f", null ],
    [ "aom_partition_features_ab_t", "group__aom__encoder.html#ga0713a9137d099e441bd6b7ed10be1b0d", null ],
    [ "aom_sb_tpl_features_t", "group__aom__encoder.html#gadb34e02e5b029504370f99a886371710", null ],
    [ "aom_sb_simple_motion_features_t", "group__aom__encoder.html#ga790f05ad7832f2614a13fd60bd3430fe", null ],
    [ "aom_sb_features_t", "group__aom__encoder.html#gacfd479b87a0dc8cb0602268f9dca37ce", null ],
    [ "aom_partition_features_t", "group__aom__encoder.html#ga2d4ad2535544500d48ac6ce6605cdf0c", null ],
    [ "aom_partition_decision_t", "group__aom__encoder.html#gae9645fe5bb80ebb66970f85bdfc81d5f", null ],
    [ "aom_partition_stats_t", "group__aom__encoder.html#gab9478e27301dfb5581f8bdf9efb40f3e", null ],
    [ "aom_ext_part_status_t", "group__aom__encoder.html#ga4af3be5d269421964fc8b3e8681121dd", null ],
    [ "aom_ext_part_create_model_fn_t", "group__aom__encoder.html#ga1a11077df0999ffba72a6fbfc8fe3331", null ],
    [ "aom_ext_part_send_features_fn_t", "group__aom__encoder.html#ga8a09d2e568a6727f6dcfa189dcb64dc0", null ],
    [ "aom_ext_part_get_decision_fn_t", "group__aom__encoder.html#gaf0c953c3c35d72df3e4bace498773be8", null ],
    [ "aom_ext_part_send_partition_stats_fn_t", "group__aom__encoder.html#ga2c864d073d251c0ed7fe8d2b71c26417", null ],
    [ "aom_ext_part_delete_model_fn_t", "group__aom__encoder.html#ga900ebe22eaa0f9296c4a876316fd4d82", null ],
    [ "aom_ext_part_funcs_t", "group__aom__encoder.html#gac18e4b6e5fd6cb617a2674cf3de3f57e", null ],
    [ "AOM_SCALING_MODE", "group__aom__encoder.html#ga8f20643dbd528f92fc0ecd96d9726d09", null ],
    [ "aom_roi_map_t", "group__aom__encoder.html#gab64a195ea67269e704df30e39a22ca42", null ],
    [ "aom_active_map_t", "group__aom__encoder.html#gadbb2fdd04ce113cdf455a6ea49109d41", null ],
    [ "aom_scaling_mode_t", "group__aom__encoder.html#ga834aa2b6069db7cc53b0a6e6b23ab557", null ],
    [ "aom_svc_layer_id_t", "group__aom__encoder.html#gacd5a13523326346771b2cf343cea96be", null ],
    [ "aom_svc_params_t", "group__aom__encoder.html#ga424f998c99e4a5584b60a41383af8dbe", null ],
    [ "aom_svc_ref_frame_config_t", "group__aom__encoder.html#gaf35292c5ec02cbfb58f06ec4889488e4", null ],
    [ "aom_svc_ref_frame_comp_pred_t", "group__aom__encoder.html#gadc27bac35ec9960f115ff1d060c75eba", null ],
    [ "aom_ext_part_decision_mode", "group__aom__encoder.html#ga7543b396ff2eef24d90b8edd094a9148", null ],
    [ "AOM_EXT_PART_FEATURE_ID", "group__aom__encoder.html#ga241e62c4cf0d5f31f56e6be63df8e566", null ],
    [ "aom_ext_part_status", "group__aom__encoder.html#ga4b28cbe3036a6f1c5753fa461facc192", [
      [ "AOM_EXT_PART_OK", "group__aom__encoder.html#gga4b28cbe3036a6f1c5753fa461facc192aee3c61f0f0cf4c7338084ae7b8368aa0", null ],
      [ "AOM_EXT_PART_ERROR", "group__aom__encoder.html#gga4b28cbe3036a6f1c5753fa461facc192a54c9174dd39c05769a23572ccebe8108", null ],
      [ "AOM_EXT_PART_TEST", "group__aom__encoder.html#gga4b28cbe3036a6f1c5753fa461facc192a31af37ff758f79b82a0d4a65ba7aa0cf", null ]
    ] ],
    [ "aome_enc_control_id", "group__aom__encoder.html#gae78dde67a6d78f332e9bdba0dde42db5", [
      [ "AOME_USE_REFERENCE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a1fd179ef74229c4b1a438521eb4ab1e4", null ],
      [ "AOME_SET_ROI_MAP", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a274f8b560c2ecc4d03e553071e89a7a4", null ],
      [ "AOME_SET_ACTIVEMAP", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a709937e1e0eb160e49720e6fd5164d1e", null ],
      [ "AOME_SET_SCALEMODE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5acc51e9ced332c76d1721a0a477500b03", null ],
      [ "AOME_SET_SPATIAL_LAYER_ID", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5aac7fbd0de7295387d7821f1889c47790", null ],
      [ "AOME_SET_CPUUSED", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5adac09e1a8da079b08fca5ccbf981f1a6", null ],
      [ "AOME_SET_ENABLEAUTOALTREF", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ac8a24393f214823f5a6bd345afb840b6", null ],
      [ "AOME_SET_SHARPNESS", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a0df0d30e82bb9683f3131138dfa2949a", null ],
      [ "AOME_SET_STATIC_THRESHOLD", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5aa4f58f6a86b710e403daeac055738111", null ],
      [ "AOME_GET_LAST_QUANTIZER", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5acf37709a88970e0dffb961d951fd43a0", null ],
      [ "AOME_GET_LAST_QUANTIZER_64", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a17b924cadd3c942f9e57fe6fc4d5e2ab", null ],
      [ "AOME_SET_ARNR_MAXFRAMES", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a327fb270f37bbb008b0f146542ce7483", null ],
      [ "AOME_SET_ARNR_STRENGTH", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5affd2c213f24a12d13bb51e31be993e60", null ],
      [ "AOME_SET_TUNING", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5aba539b6646278e7ff40f67f38639d294", null ],
      [ "AOME_SET_CQ_LEVEL", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5af67f265bf63bf8f1268b3a14ae26606c", null ],
      [ "AOME_SET_MAX_INTRA_BITRATE_PCT", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a9e1965ffa40d2d87556b65748c63adcc", null ],
      [ "AOME_SET_NUMBER_SPATIAL_LAYERS", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5aef4facbd3745aa7f2a604faaf68316ff", null ],
      [ "AV1E_SET_MAX_INTER_BITRATE_PCT", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a54b7c950e51f39a3cb7344a2665b9929", null ],
      [ "AV1E_SET_GF_CBR_BOOST_PCT", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ade327180f01d27d22abd94c1f0a8bc9e", null ],
      [ "AV1E_SET_LOSSLESS", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5afe875c6bb02f236be503c8c7b1f15875", null ],
      [ "AV1E_SET_ROW_MT", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a095d0817d339940aa2578924a840fc84", null ],
      [ "AV1E_SET_TILE_COLUMNS", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5acf4ab1ff2fa8d76a78881ad7f1a1294d", null ],
      [ "AV1E_SET_TILE_ROWS", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a57f2f2a54f593b398a5e97db7982f817", null ],
      [ "AV1E_SET_ENABLE_TPL_MODEL", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a174ffbc2e91a020a8225900e38894137", null ],
      [ "AV1E_SET_ENABLE_KEYFRAME_FILTERING", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a9a0d0eb0ab0ae8c674a96a6db11b3963", null ],
      [ "AV1E_SET_FRAME_PARALLEL_DECODING", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a465382b6bbca24467739c3c1b94e6483", null ],
      [ "AV1E_SET_ERROR_RESILIENT_MODE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5aa0d049453fced5f8079861b16e356c69", null ],
      [ "AV1E_SET_S_FRAME_MODE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a3ec44c6d8987ca88f8f635b7c098c11e", null ],
      [ "AV1E_SET_AQ_MODE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a17bd297efc31082157785d68fc5a6067", null ],
      [ "AV1E_SET_FRAME_PERIODIC_BOOST", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a737368591a37417b108c0706f7510885", null ],
      [ "AV1E_SET_NOISE_SENSITIVITY", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a8d415cd6976ea5860206e1d3cd3dd222", null ],
      [ "AV1E_SET_TUNE_CONTENT", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a2625f566fd5c2675eb2bcd40af858652", null ],
      [ "AV1E_SET_CDF_UPDATE_MODE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a277526a4a9b8c413e870ee17ff986e87", null ],
      [ "AV1E_SET_COLOR_PRIMARIES", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5af64e990728fe37287bac0874d77b22db", null ],
      [ "AV1E_SET_TRANSFER_CHARACTERISTICS", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a336fc3607a5987f9077c634f07b3cd53", null ],
      [ "AV1E_SET_MATRIX_COEFFICIENTS", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a0111ed659d2cd11827ac5cd1f3d774b0", null ],
      [ "AV1E_SET_CHROMA_SAMPLE_POSITION", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5abc5bb5cf57ba1a1193a0593225e881ff", null ],
      [ "AV1E_SET_MIN_GF_INTERVAL", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a31bcfcb7057884ceb831146c90086ddd", null ],
      [ "AV1E_SET_MAX_GF_INTERVAL", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a0355cea227ab76f9bd77028a39bbfca8", null ],
      [ "AV1E_GET_ACTIVEMAP", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a65f19811dc9057230d991647fac243b0", null ],
      [ "AV1E_SET_COLOR_RANGE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a29aa5b07bbdbdc90d7ddb148403b00ad", null ],
      [ "AV1E_SET_RENDER_SIZE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a7d462f767d5feea411c70229a3d39508", null ],
      [ "AV1E_SET_TARGET_SEQ_LEVEL_IDX", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5abc032ee5a8dc3f51ab88b64737590f1b", null ],
      [ "AV1E_GET_SEQ_LEVEL_IDX", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a726d36bbaf587cf30eb263e48a1c2e46", null ],
      [ "AV1E_SET_SUPERBLOCK_SIZE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a8854a06c62269e866d6bac0f3a2e3dc2", null ],
      [ "AOME_SET_ENABLEAUTOBWDREF", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ac03aab2de7167facffff4e22e8f89687", null ],
      [ "AV1E_SET_ENABLE_CDEF", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a6879fe104e23de00f034ed11eb605031", null ],
      [ "AV1E_SET_ENABLE_RESTORATION", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a2ea70b4b379e701a4b3b7cc33eb05e65", null ],
      [ "AV1E_SET_FORCE_VIDEO_MODE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a4fefd9e9d131485429e6c48bd5d439cf", null ],
      [ "AV1E_SET_ENABLE_OBMC", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5aa51bc0690a7d51765a01afa015ec2077", null ],
      [ "AV1E_SET_DISABLE_TRELLIS_QUANT", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a374b5581d0b68d5f8cc3e3f73495cfbb", null ],
      [ "AV1E_SET_ENABLE_QM", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ae63993934cdc5aa36efeec4df87a577e", null ],
      [ "AV1E_SET_QM_MIN", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ae611944ba148b6446d4387dd9b452917", null ],
      [ "AV1E_SET_QM_MAX", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ad897674e1b68b24ec14a01a4e3edacc7", null ],
      [ "AV1E_SET_QM_Y", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a49c0eb54ab5a4d7d6cbc97d97f3029f8", null ],
      [ "AV1E_SET_QM_U", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a5afff92787c68c2b5c50e3cfb9938504", null ],
      [ "AV1E_SET_QM_V", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a458d60628603d6c1c670d7d051634864", null ],
      [ "AV1E_SET_NUM_TG", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a9ac0044ad63e6848a482db04f0858c44", null ],
      [ "AV1E_SET_MTU", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a353037d84b6c47ac0138fa843b70a2bb", null ],
      [ "AV1E_SET_ENABLE_RECT_PARTITIONS", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5af3db44e9871c69defc5ae2cc6c5e3ba0", null ],
      [ "AV1E_SET_ENABLE_AB_PARTITIONS", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a3f494511b35631e4d400f4df9a48c6dc", null ],
      [ "AV1E_SET_ENABLE_1TO4_PARTITIONS", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ab2b627e9fad54fd84b18e73d8f6a8a51", null ],
      [ "AV1E_SET_MIN_PARTITION_SIZE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a4c1444fdafd3577606cef60afb33124c", null ],
      [ "AV1E_SET_MAX_PARTITION_SIZE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ab15141c333da6ddb99c5f2aeea934958", null ],
      [ "AV1E_SET_ENABLE_INTRA_EDGE_FILTER", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a518cc32bbf169f8e9d4d71e7c1193748", null ],
      [ "AV1E_SET_ENABLE_ORDER_HINT", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ad0eaf349d653c8357acbba84ad95d5e6", null ],
      [ "AV1E_SET_ENABLE_TX64", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ab6d4110cee235e35452d0beb89a28604", null ],
      [ "AV1E_SET_ENABLE_FLIP_IDTX", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a6c1d6fd0a0607d07cb648e4fe6702780", null ],
      [ "AV1E_SET_ENABLE_RECT_TX", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a80b982970499968059e878d56e34ed2a", null ],
      [ "AV1E_SET_ENABLE_DIST_WTD_COMP", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a80d59744d531d9e0d48c8274792b69dc", null ],
      [ "AV1E_SET_ENABLE_REF_FRAME_MVS", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a5e82346d8463bf758967abb0d03ebc88", null ],
      [ "AV1E_SET_ALLOW_REF_FRAME_MVS", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a7dc089179d789c690c91c5eb6ef6f626", null ],
      [ "AV1E_SET_ENABLE_DUAL_FILTER", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a45867a101866f7ad1a67e7d72f84054a", null ],
      [ "AV1E_SET_ENABLE_CHROMA_DELTAQ", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a44ca96b0fd8b3f6d094d7b430c7c3043", null ],
      [ "AV1E_SET_ENABLE_MASKED_COMP", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a643067b985c437490d6248decad39235", null ],
      [ "AV1E_SET_ENABLE_ONESIDED_COMP", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5adff1eda391fbe14b50ed48633dda01dc", null ],
      [ "AV1E_SET_ENABLE_INTERINTRA_COMP", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a4032b6c7ad5f4499af95ddaab863d3d6", null ],
      [ "AV1E_SET_ENABLE_SMOOTH_INTERINTRA", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5aa15748a927789e02f586d2408eaa78fe", null ],
      [ "AV1E_SET_ENABLE_DIFF_WTD_COMP", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a951b38c88fb632d63568da3cce275ecd", null ],
      [ "AV1E_SET_ENABLE_INTERINTER_WEDGE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a013aa12c1a51471d2f2f401d6abcb40d", null ],
      [ "AV1E_SET_ENABLE_INTERINTRA_WEDGE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a8b3e315575be2741071813f5a3830b79", null ],
      [ "AV1E_SET_ENABLE_GLOBAL_MOTION", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ad4da3bb77e25bac4a0afc2135617cbd9", null ],
      [ "AV1E_SET_ENABLE_WARPED_MOTION", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a4c4ae7f4158f795667b16c99fcdc5dd3", null ],
      [ "AV1E_SET_ALLOW_WARPED_MOTION", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5afbc7110685278814b7993be4d185b9ca", null ],
      [ "AV1E_SET_ENABLE_FILTER_INTRA", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a9774262de47ffd2bb7d674bb55951a7e", null ],
      [ "AV1E_SET_ENABLE_SMOOTH_INTRA", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a0a1d54150968c5c20b410bc29dc0caa4", null ],
      [ "AV1E_SET_ENABLE_PAETH_INTRA", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a25f7c646aaec0702964c1fb1bf16e298", null ],
      [ "AV1E_SET_ENABLE_CFL_INTRA", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a993e0e437aa0d152fe654ba0ab46f9d2", null ],
      [ "AV1E_SET_ENABLE_SUPERRES", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a86e399de03aa825bb7e594e3df1bf71b", null ],
      [ "AV1E_SET_ENABLE_OVERLAY", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5aeb92db47fea74d34938668ee62bb565e", null ],
      [ "AV1E_SET_ENABLE_PALETTE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a98d0e84130317b6c072c2deac106dede", null ],
      [ "AV1E_SET_ENABLE_INTRABC", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a3e59c51f12c7350fee92c1c0d4901ab0", null ],
      [ "AV1E_SET_ENABLE_ANGLE_DELTA", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a3155057080db493c868eb2d42d435b61", null ],
      [ "AV1E_SET_DELTAQ_MODE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ad26eda6211bf3d5fe4f5999ec52b264b", null ],
      [ "AV1E_SET_DELTALF_MODE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ab2d0e42bcf19974859e61d8709c5ae09", null ],
      [ "AV1E_SET_SINGLE_TILE_DECODING", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5af341538631ffe2ac2b562c8b5336a10a", null ],
      [ "AV1E_ENABLE_MOTION_VECTOR_UNIT_TEST", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a0c45a2184ff7068f470cb9f128c3605d", null ],
      [ "AV1E_SET_TIMING_INFO_TYPE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a857e822046c62a4c774b1d16c4e453dd", null ],
      [ "AV1E_SET_FILM_GRAIN_TEST_VECTOR", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a437e6b282a2395b4b08a9acde3e41cfb", null ],
      [ "AV1E_SET_FILM_GRAIN_TABLE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ad5846c6f49d37e65a03c39e68d487097", null ],
      [ "AV1E_SET_DENOISE_NOISE_LEVEL", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a54fe460f126a7566aa627cd82826faf0", null ],
      [ "AV1E_SET_DENOISE_BLOCK_SIZE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ae113c7e68a6c39b872a268ed6cdf6d10", null ],
      [ "AV1E_SET_CHROMA_SUBSAMPLING_X", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a283dd3f4387e5f3a754fea0d206b1cb0", null ],
      [ "AV1E_SET_CHROMA_SUBSAMPLING_Y", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a501a9453d5790f32c001e9877d3db40c", null ],
      [ "AV1E_SET_REDUCED_TX_TYPE_SET", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5abc82eae151e4a5050dbc324b5d16be2d", null ],
      [ "AV1E_SET_INTRA_DCT_ONLY", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a56dd8bdd23f09e24e2afea7633f20e74", null ],
      [ "AV1E_SET_INTER_DCT_ONLY", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ac3dcd39257d82c1be99a8752bef6f20b", null ],
      [ "AV1E_SET_INTRA_DEFAULT_TX_ONLY", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a335eed63dd36dd6e9a83a462c3c15fe1", null ],
      [ "AV1E_SET_QUANT_B_ADAPT", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a953968db8a041da6fe727add815ad53e", null ],
      [ "AV1E_SET_GF_MAX_PYRAMID_HEIGHT", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a685f831a5a5d08f9b5a14209d55ac129", null ],
      [ "AV1E_SET_MAX_REFERENCE_FRAMES", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5adaa8c4b0f736003b552d1d7d68877f6f", null ],
      [ "AV1E_SET_REDUCED_REFERENCE_SET", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a17fe8deb975a641c65d1dce6b5e3a4e0", null ],
      [ "AV1E_SET_COEFF_COST_UPD_FREQ", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a542a607e7d8c6a3d8244136b3e09da4b", null ],
      [ "AV1E_SET_MODE_COST_UPD_FREQ", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5afb9a186506424be1020cdd8c79342b7a", null ],
      [ "AV1E_SET_MV_COST_UPD_FREQ", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a333c3281f6f0b11bd475f303bee9ec6e", null ],
      [ "AV1E_SET_TIER_MASK", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a8a9265ce765bdcf9df119a7e5c7b3cc7", null ],
      [ "AV1E_SET_MIN_CR", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5afe2dd2cf29cc6202786ecbf132288d99", null ],
      [ "AV1E_SET_SVC_LAYER_ID", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a1d968f9cc0ad869e36680328b0badaf7", null ],
      [ "AV1E_SET_SVC_PARAMS", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a94c12c49cd70d86651136ec37230d719", null ],
      [ "AV1E_SET_SVC_REF_FRAME_CONFIG", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a24a2e10051709d0684d8b7acfbf988c9", null ],
      [ "AV1E_SET_VMAF_MODEL_PATH", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ae37ef21d3de7325b37fe4700cafdc1d3", null ],
      [ "AV1E_ENABLE_EXT_TILE_DEBUG", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5afc3b5989c7494bcda0dbe8f62a8ee680", null ],
      [ "AV1E_ENABLE_SB_MULTIPASS_UNIT_TEST", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ad0988ccfb2ba74b56fc3f0c037b92997", null ],
      [ "AV1E_SET_GF_MIN_PYRAMID_HEIGHT", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a250c4c30488f4cd7108bf1c99515190e", null ],
      [ "AV1E_SET_VBR_CORPUS_COMPLEXITY_LAP", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a6810fa1bb5b3b9a58063006e1f894542", null ],
      [ "AV1E_GET_BASELINE_GF_INTERVAL", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a9c7e2ff5a2228bcd5c524c03ef60adc6", null ],
      [ "AV1E_SET_ENABLE_DIAGONAL_INTRA", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a020292f1be3c8697766c6f190b1eef9e", null ],
      [ "AV1E_SET_DV_COST_UPD_FREQ", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a784231ebe03cdcd4ad77a2e3f7f0343e", null ],
      [ "AV1E_SET_PARTITION_INFO_PATH", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5aa82ae17ed56d93d8f5901afbd2da172e", null ],
      [ "AV1E_SET_EXTERNAL_PARTITION", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ad041aa24f16d1d35c59ccbe4ff8ba420", null ],
      [ "AV1E_SET_ENABLE_DIRECTIONAL_INTRA", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a54ad2c50072ecedbbcbe75df577afabd", null ],
      [ "AV1E_SET_ENABLE_TX_SIZE_SEARCH", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5af9928b5094d367d21363784ddab11139", null ],
      [ "AV1E_SET_SVC_REF_FRAME_COMP_PRED", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a3bf579936cd7dc5e0a35e10e40a96ce9", null ],
      [ "AV1E_SET_DELTAQ_STRENGTH", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5abd4ce26a7a8883f057e217c2a7fa86a2", null ],
      [ "AV1E_SET_LOOPFILTER_CONTROL", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ac4c69bc7114841f8e57d4ea75dc147fd", null ],
      [ "AOME_GET_LOOPFILTER_LEVEL", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a72c1d1e8be8ce0dd3f9b95751ec73acd", null ]
    ] ],
    [ "aom_scaling_mode_1d", "group__aom__encoder.html#ga2a1791d26fca39303154f0f9ece3e295", null ],
    [ "aom_tune_content", "group__aom__encoder.html#ga801f5eb2cb93da19a2f347ae7a44166a", null ],
    [ "aom_timing_info_type_t", "group__aom__encoder.html#gad69c1d6aa10530991eeb1a3f0a818cba", null ],
    [ "aom_tune_metric", "group__aom__encoder.html#gaafd352cc596fab5388558950f8bbe739", null ],
    [ "aom_codec_av1_cx", "group__aom__encoder.html#ga77adf3b7884b3619a4c5cbc236fe9de5", null ],
    [ "aom_codec_av1_cx_algo", "group__aom__encoder.html#ga18350b1c0642494e2b1a970104b2e8b9", null ]
];